@@ -3,6 +3,10 @@ from conans import ConanFile
 from sense2.model.layout import Folders
 
 class Sense2File(ConanFile):
+
+    apt_user = ""
+    apt_server = ""
+
     def __init__(self, output, runner, display_name="", user=None, channel=None):
         super().__init__(output, runner, display_name, user, channel)
         # layout() method related variables:
